isPhoneNumberRequired property
Indicates whether a phone number is required in the billing address.
Implementation
final bool isPhoneNumberRequired;
Indicates whether a phone number is required in the billing address.
final bool isPhoneNumberRequired;