PaymentResult class
A class to hold the structured result of a payment operation.
Constructors
- PaymentResult(PaymentStatus status, String? reason)
- Creates a new PaymentResult.
- PaymentResult.fromMap(Map map)
-
A factory constructor to create a
PaymentResultfrom a map received from the native side. This is used internally by the plugin.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- reason → String?
-
An optional string providing more details about the result, especially for failures.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → PaymentStatus
-
The final status of the payment.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited